import { FC, PropsWithChildren, ReactNode, AnchorHTMLAttributes, ButtonHTMLAttributes, HTMLAttributes, InputHTMLAttributes, OptionHTMLAttributes, ProgressHTMLAttributes, SelectHTMLAttributes, TableHTMLAttributes, TextareaHTMLAttributes } from "react";
import { ClassnamesArg } from "./classnames.js";
import { ClassNames as Bulma } from "./Bulma.js";
export type MainColor = "danger" | "link" | "info" | "primary" | "success" | "warning";
export type ShadeColor = "black" | "dark" | "light" | "white";
export type OtherColor = "text" | "ghost";
export type Color = MainColor | ShadeColor | OtherColor;
export type ColorVariant = "light" | "dark";
export type Alignment = "left" | "center" | "right";
export type Size = "small" | "medium" | "large" | "normal";
export type PluralSize = Extract<Size, "small" | "medium" | "large">;
export type BulmaProp = {
    bulma?: ClassnamesArg<Bulma>;
};
export type AlignProp<A extends Alignment> = Partial<{
    align: A;
}>;
export type ColorProp<C extends Color = Color> = Partial<{
    color: C;
}>;
export type ColorVariantProp<V extends ColorVariant = ColorVariant> = Partial<{
    variant: V;
}>;
export type IsActiveProp = Partial<{
    isActive: boolean;
}>;
export type IsSkeletonProp = Partial<{
    isSkeleton: boolean;
}>;
export type SizeProp<S extends Size = Extract<Size, "small" | "medium" | "large">> = Partial<{
    size: S;
}>;
export type TagProp<T extends keyof JSX.IntrinsicElements> = Partial<{
    tag: T;
}>;
export type PluralSizeProp = SizeProp<PluralSize>;
/**
 * Renders anchor tag, has `bulma` prop.
 *
 * @example
 * ```tsx
 * <A href="https://example.com" bulma="is-underlined">Website</A>
 * ```
 */
export declare const A: FC<PropsWithChildren<AProps>>;
export type AProps = AnchorHTMLAttributes<HTMLAnchorElement> & BulmaProp;
/**
 * Renders div tag, has `bulma` prop.
 *
 * @example Block
 * ```tsx
 * <Div bulma="block"></Div>
 * ```
 *
 * @example Skeleton block
 * ```tsx
 * <Div bulma={{"skeleton-block": true}}>
 *   Lorem ipsum
 * </Div>
 * ```
 */
export declare const Div: FC<PropsWithChildren<DivProps>>;
export type DivProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/**
 * Renders p tag, has `bulma` prop.
 *
 * @example
 * ```tsx
 * <P bulma="has-text-grey">Lorem ipsum...</P>
 * ```
 */
export declare const P: FC<PropsWithChildren<PProps>>;
export type PProps = HTMLAttributes<HTMLParagraphElement> & BulmaProp;
/**
 * Renders span tag, has `bulma` prop.
 *
 * @example
 * ```tsx
 * <Span bulma={["has-text-grey", "is-capitalized"]}>hello</Span>
 * ```
 */
export declare const Span: FC<PropsWithChildren<SpanProps>>;
export type SpanProps = HTMLAttributes<HTMLSpanElement> & BulmaProp;
/**
 * A breadcrumb component to improve navigation experience.
 *
 * @example
 * ```tsx
 * <Breadcrumb align="center" aria-label="breadcrumbs">
 *   <BreadcrumbItem href="https://bulma.io/">Bulma</BreadcrumbItem>
 *   <BreadcrumbItem isActive>Trunx</BreadcrumbItem>
 * </Breadcrumb>
 * ```
 *
 * @example Alternative separator and size
 * ```tsx
 * <Breadcrumb separator="dot" size="small">
 * </Breadcrumb>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/breadcrumb/)
 */
export declare const Breadcrumb: FC<PropsWithChildren<BreadcrumbProps> & BulmaProp>;
export type BreadcrumbProps = HTMLAttributes<HTMLElement> & BulmaProp & AlignProp<"center" | "right"> & SizeProp & Partial<{
    separator: "arrow" | "bullet" | "dot" | "succeeds";
}>;
/** @see {@link Breadcrumb} */
export declare const BreadcrumbItem: FC<PropsWithChildren<BreadcrumbItemProps>>;
export type BreadcrumbItemProps = AnchorHTMLAttributes<HTMLAnchorElement> & IsActiveProp;
/**
 * The classic button, in different colors, sizes, and states.
 *
 * @example
 * ```tsx
 * <Button color="primary" variant="light" isLoading>Login</Button>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/button/)
 */
export declare const Button: FC<PropsWithChildren<ButtonProps>>;
export type ButtonProps = Omit<ButtonHTMLAttributes<HTMLButtonElement>, "color"> & BulmaProp & ColorProp & ColorVariantProp & IsSkeletonProp & SizeProp<Size> & Partial<{
    isLoading: boolean;
    isInverted: boolean;
    isFullwidth: boolean;
    isOutlined: boolean;
    isResponsive: boolean;
    isRounded: boolean;
}>;
/**
 * Can create a list of buttons.
 *
 * @example
 * ```tsx
 * <Buttons size="small">
 *   <Button color="success">Save</Button>
 *   <Button>Cancel</Button>
 * </Buttons>
 * ```
 */
export declare const Buttons: FC<PropsWithChildren<ButtonsProps>>;
export type ButtonsProps = HTMLAttributes<HTMLDivElement> & BulmaProp & PluralSizeProp;
/**
 * Grid cell.
 *
 * @example
 * ```tsx
 * <FixedGrid bulma="has-4-cols">
 *   <Cell>cell 1</Cell>
 *   <Cell bulma="is-col-start-3">cell 2</Cell>
 *   <Cell>cell 3</Cell>
 *   <Cell>cell 4</Cell>
 *   <Cell>cell 5</Cell>
 *   <Cell>cell 6</Cell>
 * </FixedGrid>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/grid/grid-cells/)
 *
 * Nope! 😂 Not that {@link https://en.wikipedia.org/wiki/Cell_(Dragon_Ball) | Cell}
 */
export declare const Cell: FC<PropsWithChildren<CellProps>>;
export type CellProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/**
 * An all-around flexible and composable component.
 *
 * @example
 * ```tsx
 * <Card>
 *   <CardHeader>
 *     <CardHeaderTitle>Title</CardHeaderTitle>
 *     <CardHeaderIcon>
 *       <Icon><i className="fas fa-angle-down" aria-hidden="true" /></Icon>
 *     </CardHeaderIcon>
 *   </CardHeader>
 *   <CardContent>
 *     Lorem ipsum...
 *   </CardContent>
 *   <CardFooter>
 *     <A bulma="card-footer-item">Save</A>
 *     <A bulma="card-footer-item">Delete</A>
 *   </CardFooter>
 * </Card>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/card/)
 */
export declare const Card: FC<PropsWithChildren<CardProps>>;
export type CardProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/** @see {@link Card} */
export declare const CardContent: FC<PropsWithChildren<CardContentProps>>;
export type CardContentProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/** @see {@link Card} */
export declare const CardFooter: FC<PropsWithChildren<CardFooterProps>>;
export type CardFooterProps = HTMLAttributes<HTMLElement> & BulmaProp;
/** @see {@link Card} */
export declare const CardHeader: FC<PropsWithChildren<CardHeaderProps>>;
export type CardHeaderProps = HTMLAttributes<HTMLElement> & BulmaProp;
/** @see {@link Card} */
export declare const CardHeaderIcon: FC<PropsWithChildren<CardHeaderIconProps>>;
export type CardHeaderIconProps = HTMLAttributes<HTMLButtonElement> & BulmaProp;
/** @see {@link Card} */
export declare const CardHeaderTitle: FC<PropsWithChildren<CardHeaderTitleProps>>;
export type CardHeaderTitleProps = HTMLAttributes<HTMLParagraphElement> & BulmaProp;
/**
 * The 2-state checkbox in its native format
 *
 * @example
 * ```tsx
 * <Checkbox disabled>
 *   <Span bulma="ml-2">Save my preferences</Span>
 * </Checkbox>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/checkbox/)
 */
export declare const Checkbox: FC<PropsWithChildren<CheckboxProps>>;
export type CheckboxProps = Omit<InputHTMLAttributes<HTMLInputElement>, "type">;
/** @see {@link Columns} */
export declare const Column: FC<PropsWithChildren<ColumnProps>>;
export type ColumnProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/**
 * The power of Flexbox in a simple interface.
 *
 * @see [bulma docs](https://bulma.io/documentation/columns/)
 */
export declare const Columns: FC<PropsWithChildren<ColumnsProps>>;
export type ColumnsProps = HTMLAttributes<HTMLDivElement> & BulmaProp & Partial<{
    isGapless: boolean;
    isDesktop: boolean;
    isMobile: boolean;
    isMultiline: boolean;
}>;
/**
 * A simple container to center your content horizontally.
 *
 * @example
 * ```tsx
 * <Container isFluid>
 *   <Notification color="primary">
 *     This container is <strong>fluid</strong>
 *   </Notification>
 * </Container>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/layout/container/)
 */
export declare const Container: FC<PropsWithChildren<ContainerProps>>;
export type ContainerProps = HTMLAttributes<HTMLDivElement> & BulmaProp & Partial<{
    isMax: "desktop" | "widescreen";
    isWidescreen: boolean;
    isFluid: boolean;
    isFullhd: boolean;
}>;
/**
 * A container for text.
 *
 * @example
 * <Content size="small">
 *   <h1>Hello World</h1>
 *   <p>Lorem ipsum...</p>
 * </Content>
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/content/)
 */
export declare const Content: FC<PropsWithChildren<ContentProps>>;
export type ContentProps = HTMLAttributes<HTMLDivElement> & BulmaProp & IsSkeletonProp & SizeProp;
export declare const Control: FC<PropsWithChildren<ControlProps>>;
export type ControlProps = HTMLAttributes<HTMLDivElement> & BulmaProp & Partial<{
    isExpanded: boolean;
    hasIconsLeft: boolean;
    hasIconsRight: boolean;
}>;
/**
 * A versatile delete cross.
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/delete/)
 */
export declare const Delete: FC<DeleteProps>;
export type DeleteProps = ButtonHTMLAttributes<HTMLButtonElement> & SizeProp;
/**
 * Form field.
 *
 * @example
 * ```tsx
 * <Field>
 *   <Label>Name</Label>
 *   <Control>
 *     <Input placeholder="e.g Alex Smith" />
 *   </Control>
 * </Field>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/general/#form-field)
 */
export declare const Field: FC<PropsWithChildren<FieldProps>>;
export type FieldProps = HTMLAttributes<HTMLDivElement> & BulmaProp & Partial<{
    hasAddons: boolean | "centered" | "right";
    hasAddonsCentered: boolean;
    hasAddonsRight: boolean;
    isGrouped: boolean | "centered" | "multiline" | "right";
    isHorizontal: boolean;
}>;
/** @see {@link FieldHorizontal} */
export declare const FieldBody: FC<PropsWithChildren<FieldBodyProps>>;
export type FieldBodyProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/**
 * A horizontal form control.
 *
 * @example
 * ```tsx
 * <FieldHorizontal>
 *   <FieldLabel isNormal>
 *     <Label>From</Label>
 *   </FieldLabel>
 *   <FieldBody>
 *     <Field>
 *       <Control>
 *         <Input type="text" placeholder="Name" />
 *       </Control>
 *     </Field>
 *     <Field>
 *       <Control>
 *         <Input type="email" placeholder="Email" />
 *       </Control>
 *     </Field>
 *   </FieldBody>
 * </FieldHorizontal>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/general/#horizontal-form)
 */
export declare const FieldHorizontal: FC<PropsWithChildren<FieldHorizontalProps>>;
export type FieldHorizontalProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/** @see {@link FieldHorizontal} */
export declare const FieldLabel: FC<PropsWithChildren<FieldLabelProps>>;
export type FieldLabelProps = HTMLAttributes<HTMLDivElement> & BulmaProp & {
    isNormal: boolean;
};
/**
 * A custom file upload input.
 *
 * @example
 * ```tsx
 * <FileUpload
 *   cta={<>
 *     <FileIcon><i className="fas fa-upload"></i></FileIcon>
 *     <FileLabel>Choose a file...</FileLabel>
 *   </>}
 *   // Any prop accepted by input type="file"
 *   accept="image/png, image/jpeg"
 *   name="avatar"
 * />
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/file/)
 */
export declare const FileUpload: FC<FileUploadProps>;
export type FileUploadProps = Omit<InputHTMLAttributes<HTMLInputElement>, "size" | "type"> & BulmaProp & AlignProp<"center" | "right"> & ColorProp & SizeProp & Partial<{
    cta: ReactNode;
    hasName: ReactNode;
    isBoxed: boolean;
    isFullwidth: boolean;
}>;
/** @see {@link FileUpload} */
export declare const FileIcon: FC<PropsWithChildren<FileIconProps>>;
export type FileIconProps = HTMLAttributes<HTMLSpanElement> & BulmaProp;
/** @see {@link FileUpload} */
export declare const FileLabel: FC<PropsWithChildren<FileLabelProps>>;
export type FileLabelProps = HTMLAttributes<HTMLSpanElement> & BulmaProp;
/**
 * A customizable 2D fixed grid.
 *
 * @example
 * ```tsx
 * <FixedGrid hasAutoCount>
 *   <Cell>cell 1</Cell>
 *   <Cell>cell 2</Cell>
 * </FixedGrid>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/grid/fixed-grid/)
 */
export declare const FixedGrid: FC<PropsWithChildren<FixedGridProps>>;
export type FixedGridProps = HTMLAttributes<HTMLDivElement> & BulmaProp & Partial<{
    hasAutoCount: boolean;
}>;
/** A simple responsive footer.
 *
 * @example
 * ```tsx
 * <Footer>
 *   <Content bulma="has-text-centered">
 *     <p>
 *       <strong>trunx</strong> by <a href="https://fibo.github.io">fibo</a>.
 *       The source code is licensed
 *       <a href="http://opensource.org/licenses/mit-license.php">MIT</a>.
 *     </p>
 *   </Content>
 * </Footer>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/layout/footer/)
 */
export declare const Footer: FC<PropsWithChildren<FooterProps>>;
export type FooterProps = HTMLAttributes<HTMLElement> & BulmaProp;
/**
 * A smart 2D grid with flexible columns.
 *
 * @example
 * ```tsx
 * <Grid bulma={["is-col-min-4", "is-gap-2"]}>
 *   <Cell>cell 1</Cell>
 *   <Cell>cell 2</Cell>
 * </Grid>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/grid/smart-grid/)
 */
export declare const Grid: FC<PropsWithChildren<GridProps>>;
export type GridProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
export declare const Help: FC<PropsWithChildren<HelpProps>>;
export type HelpProps = HTMLAttributes<HTMLParagraphElement> & BulmaProp & ColorProp;
/**
 * An imposing hero banner to showcase something.
 *
 * @example
 * ```tsx
 * <Hero size="small">
 *   <HeroBody>
 *     <Title>Title</Title>
 *     <Subtitle>Subtitle</Subtitle>
 *   </HeroBody>
 * </Hero>
 * ```
 *
 * @example Half height hero
 * ```tsx
 * <Hero color="success" isHalfheight>
 *   <HeroBody>
 *     <Title>Title</Title>
 *     <Subtitle>Subtitle</Subtitle>
 *   </HeroBody>
 * </Hero>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/layout/hero/)
 */
export declare const Hero: FC<PropsWithChildren<HeroProps>>;
export type HeroProps = HTMLAttributes<HTMLElement> & BulmaProp & ColorProp & SizeProp & Partial<{
    isHalfheight: boolean;
    isFullheight: boolean;
    isFullheightWithNavbar: boolean;
}>;
/** @see {@link Hero} */
export declare const HeroBody: FC<PropsWithChildren<HeroBodyProps>>;
export type HeroBodyProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/** @see {@link Hero} */
export declare const HeroFoot: FC<PropsWithChildren<HeroFootProps>>;
export type HeroFootProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/** @see {@link Hero} */
export declare const HeroHead: FC<PropsWithChildren<HeroHeadProps>>;
export type HeroHeadProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/**
 * A container for any type of icon.
 *
 * @example
 * ```tsx
 * <Icon>
 *   <i className="fas fa-home"></i>
 * </Icon>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/icon/).
 */
export declare const Icon: FC<PropsWithChildren<IconProps>>;
export type IconProps = HTMLAttributes<HTMLSpanElement> & BulmaProp & AlignProp<"left" | "right"> & IsSkeletonProp & SizeProp;
/**
 * Combine an icon with text.
 *
 * @example
 * ```tsx
 * <IconText>
 *   <Icon bulma="has-text-primary">
 *     <i className="fas fa-home"></i>
 *   </Icon>
 *   <span>Home</span>
 * </IconText>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/icon/#icon-text)
 */
export declare const IconText: FC<PropsWithChildren<IconTextProps>>;
export type IconTextProps = HTMLAttributes<HTMLSpanElement> & BulmaProp & SizeProp;
/**
 * A container for responsive images.
 *
 * @example Fixed square images
 * ```tsx
 * <Image dimension="128x128">
 *   <img src="https://bulma.io/assets/images/placeholders/128x128.png" />
 * </Image>
 * ```
 *
 * @example Rounded images
 * ```tsx
 * <Image dimension="128x128">
 *   <img className="is-rounded" src="https://bulma.io/assets/images/placeholders/256x256.png" />
 * </Image>
 * ```
 *
 * @example Arbitrary ratios with any element
 * ```tsx
 * <Image ratio="16by9">
 *   <iframe
 *     className="has-ratio"
 *     width="640"
 *     height="360"
 *     src="https://www.youtube.com/embed/YE7VzlLtp-4"
 *     allowFullScreen
 *   />
 * </Image>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/image/)
 */
export declare const Image: FC<PropsWithChildren<ImageProps>>;
export type ImageProps = HTMLAttributes<HTMLElement> & BulmaProp & IsSkeletonProp & Partial<{
    isSquare: boolean;
    dimension: ImageDimension;
    ratio: "1by1" | "5by4" | "4by3" | "3by2" | "5by3" | "16by9" | "2by1" | "3by1" | "4by5" | "3by4" | "2by3" | "3by5" | "9by16" | "1by2" | "1by3";
}>;
export type ImageDimension = "16x16" | "24x24" | "32x32" | "48x48" | "64x64" | "96x96" | "128x128";
export declare const Input: FC<InputProps>;
export type InputProps = Omit<InputHTMLAttributes<HTMLInputElement>, "size" | "type"> & Partial<{
    type: Exclude<InputHTMLAttributes<HTMLInputElement>["type"], "checkbox" | "file" | "radio">;
}> & BulmaProp & ColorProp & IsSkeletonProp & SizeProp;
/** Renders label tag with label class. */
export declare const Label: FC<PropsWithChildren<LabelProps>>;
export type LabelProps = HTMLAttributes<HTMLLabelElement> & BulmaProp;
/**
 * The famous media object prevalent in social media interfaces.
 *
 * @example
 * ```tsx
 * <Media>
 *   <MediaLeft dimension="64x64">
 *     <img src="https://bulma.io/assets/images/placeholders/128x128.png" />
 *   </MediaLeft>
 *   <MediaContent>
 *     Content
 *   </MediaContent>
 *   <MediaRight>
 *     <Delete />
 *   </MediaRight>
 * </Media>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/layout/media-object/)
 */
export declare const Media: FC<PropsWithChildren<MediaProps>>;
export type MediaProps = HTMLAttributes<HTMLElement> & BulmaProp;
/** @see {@link Media} */
export declare const MediaContent: FC<PropsWithChildren<MediaContentProps>>;
export type MediaContentProps = HTMLAttributes<HTMLElement> & BulmaProp;
/** @see {@link Media} */
export declare const MediaLeft: FC<PropsWithChildren<MediaLeftProps>>;
export type MediaLeftProps = HTMLAttributes<HTMLElement> & BulmaProp & {
    dimension: ImageDimension;
};
/** @see {@link Media} */
export declare const MediaRight: FC<PropsWithChildren<MediaRightProps>>;
export type MediaRightProps = HTMLAttributes<HTMLElement> & BulmaProp;
/**
 * A simple menu, for any type of vertical navigation.
 *
 * Renders aside tag with menu class.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/menu/)
 */
export declare const Menu: FC<PropsWithChildren<MenuProps>>;
export type MenuProps = HTMLAttributes<HTMLElement> & BulmaProp;
/** Renders p tag with menu-label class. */
export declare const MenuLabel: FC<PropsWithChildren<MenuLabelProps>>;
export type MenuLabelProps = HTMLAttributes<HTMLParagraphElement> & BulmaProp;
/** Renders ul tag with menu-list class. */
export declare const MenuList: FC<PropsWithChildren<MenuListProps>>;
export type MenuListProps = HTMLAttributes<HTMLUListElement> & BulmaProp;
/**
 * Colored message blocks, to emphasize part of your page.
 *
 * @example
 * ```tsx
 * <Message color="danger" size="large">Lorem ipsum...</Message>
 * ```
 *
 * @example Optional header can hold a title and a Delete component.
 * ```tsx
 * <Message color="dark"
 *   header={
 *     <>
 *       <p>Header</p>
 *       <Delete />
 *     </>
 *   }
 * >Lorem ipsum...</Message>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/message/)
 */
export declare const Message: FC<PropsWithChildren<MessageProps>>;
export type MessageProps = Omit<HTMLAttributes<HTMLElement>, "color"> & BulmaProp & ColorProp & SizeProp & Partial<{
    header: ReactNode;
}>;
/**
 * A classic modal overlay, in which you can include any content you want.
 *
 * Renders div tag with modal class.
 *
 * ```tsx
 * <Modal noBackground>
 *   <ModalContent>
 *     Content
 *   </ModalContent>
 *   <ModalClose />
 * </Modal>
 * ```
 * @see [bulma docs](https://bulma.io/documentation/components/modal/)
 */
export declare const Modal: FC<PropsWithChildren<ModalProps>>;
export type ModalProps = HTMLAttributes<HTMLDivElement> & BulmaProp & SizeProp & Partial<{
    noBackground: boolean;
}>;
/**
 * A modal with a head, a body and a foot.
 *
 * Renders div tag with modal-card class.
 *
 * @example
 * ```tsx
 * <ModalCard
 *   head="Modal title"
 *   foot={<Buttons><Button>Ok</Button></Buttons>}
 * >
 *   Content ...
 * </ModalCard>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/modal/#modal-card)
 */
export declare const ModalCard: FC<PropsWithChildren<ModalCardProps>>;
export type ModalCardProps = HTMLAttributes<HTMLDivElement> & {
    head: ReactNode;
    foot: ReactNode;
};
/** Renders button tag with modal-close class. */
export declare const ModalClose: FC<ModalCloseProps>;
export type ModalCloseProps = ButtonHTMLAttributes<HTMLButtonElement> & SizeProp<"large">;
/** Renders div tag with modal-content class. */
export declare const ModalContent: FC<PropsWithChildren<ModalContentProps>>;
export type ModalContentProps = HTMLAttributes<HTMLDivElement> & BulmaProp;
/**
 * A responsive horizontal navbar that can support images, links, buttons, and dropdowns.
 *
 * Renders nav tag with navbar class.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/navbar/)
 */
export declare const Navbar: FC<PropsWithChildren<NavbarProps>>;
export type NavbarProps = Omit<HTMLAttributes<HTMLElement>, "color"> & BulmaProp & ColorProp<MainColor | ShadeColor>;
/**
 * The NavbarBrand is the left side of the navbar.
 *
 * Renders div tag with navbar-brand class.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/navbar/#navbar-brand)
 */
export declare const NavbarBrand: FC<PropsWithChildren>;
/**
 * The NavbarBurger is a hamburger menu that only appears on touch devices.
 *
 * Renders a tag with navbar-burger class.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/navbar/#navbar-burger)
 */
export declare const NavbarBurger: FC<NavbarBurgerProps>;
export type NavbarBurgerProps = Omit<HTMLAttributes<HTMLElement>, "aria-label" | "className" | "role"> & IsActiveProp;
/** Renders hr tag with navbar-divider class. */
export declare const NavbarDivider: FC;
export declare const NavbarDropdown: FC<PropsWithChildren<NavbarDropdownProps>>;
export type NavbarDropdownProps = HTMLAttributes<HTMLDivElement> & BulmaProp & AlignProp<"right"> & Partial<{
    isBoxed: boolean;
    isRight: boolean;
}>;
export declare const NavbarDropdownMenu: FC<PropsWithChildren<NavbarDropdownMenuProps>>;
export type NavbarDropdownMenuProps = HTMLAttributes<HTMLDivElement> & BulmaProp & IsActiveProp & Partial<{
    hasDropdownUp: boolean;
    isHoverable: boolean;
}>;
export declare const NavbarEnd: FC<PropsWithChildren>;
export declare const NavbarItem: FC<PropsWithChildren<NavbarItemProps>>;
export type NavbarItemProps = AnchorHTMLAttributes<HTMLAnchorElement> & BulmaProp & Partial<{
    isSelected: boolean;
}>;
export declare const NavbarLink: FC<PropsWithChildren<NavbarLinkProps>>;
export type NavbarLinkProps = AnchorHTMLAttributes<HTMLAnchorElement> & BulmaProp & Partial<{
    isArrowless: boolean;
}>;
/**
 * The NavbarMenu is the counterpart of the NavbarBrand. As such, it must appear as a direct child of Navbar, as a sibling of NavbarBrand.
 *
 * @example
 * ```tsx
 * <NavbarMenu>
 *   <NavbarStart>
 *     // Navbar items
 *   </NavbarStart>
 *   <NavbarEnd>
 *     // Navbar items
 *   </NavbarEnd>
 * </NavbarMenu>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/navbar/#navbar-menu)
 */
export declare const NavbarMenu: FC<PropsWithChildren<NavbarMenuProps>>;
export type NavbarMenuProps = IsActiveProp;
export declare const NavbarStart: FC<PropsWithChildren>;
/**
 * Bold notification blocks, to alert your users of something.
 *
 * Renders div tag with notification class.
 *
 * @example
 * ```tsx
 * <Notification color="info" variant="light">
 *   <Delete />
 *   Lorem ipsum...
 * </Notification>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/notification/)
 */
export declare const Notification: FC<PropsWithChildren<NotificationProps>>;
export type NotificationProps = HTMLAttributes<HTMLDivElement> & BulmaProp & ColorProp & ColorVariantProp<"light"> & IsSkeletonProp;
/**
 * A responsive, usable, and flexible pagination.
 *
 * @see [bulma docs](https://bulma.io/documentation/components/pagination/)
 */
export declare const Pagination: FC<PropsWithChildren<PaginationProps>>;
export type PaginationProps = HTMLAttributes<HTMLElement> & BulmaProp & AlignProp<"center" | "right"> & SizeProp;
export declare const PaginationEllipsis: FC;
export declare const PaginationLink: FC<PropsWithChildren<PaginationLinkProps>>;
export type PaginationLinkProps = AnchorHTMLAttributes<HTMLAnchorElement> & BulmaProp & Partial<{
    isCurrent: boolean;
}>;
export declare const PaginationList: FC<PropsWithChildren<PaginationListProps>>;
export type PaginationListProps = HTMLAttributes<HTMLUListElement> & BulmaProp;
export declare const PaginationNext: FC<PropsWithChildren<PaginationNextProps>>;
export type PaginationNextProps = AnchorHTMLAttributes<HTMLAnchorElement> & BulmaProp & Partial<{
    isDisabled: boolean;
}>;
export declare const PaginationPrevious: FC<PropsWithChildren<PaginationPreviousProps>>;
export type PaginationPreviousProps = AnchorHTMLAttributes<HTMLAnchorElement> & BulmaProp & Partial<{
    isDisabled: boolean;
}>;
/**
 * Native HTML progress bars.
 *
 * @example
 * ```tsx
 * <Progress color="primary" size="small" value="42" max="100">42%</Progress>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/progress/)
 */
export declare const Progress: FC<PropsWithChildren<ProgressProps>>;
export type ProgressProps = ProgressHTMLAttributes<HTMLProgressElement> & BulmaProp & SizeProp;
export declare const Radio: FC<PropsWithChildren<RadioProps>>;
export type RadioProps = Omit<InputHTMLAttributes<HTMLInputElement>, "type"> & BulmaProp;
/**
 * A simple container to divide your page into sections.
 *
 * @example
 * ```tsx
 * <Section size="medium">
 *   <Title tag="h2">Title</Title>
 * </Section>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/layout/section/)
 */
export declare const Section: FC<PropsWithChildren<SectionProps>>;
export type SectionProps = HTMLAttributes<HTMLElement> & BulmaProp & SizeProp<"medium" | "large">;
/**
 * The browser built-in select dropdown, styled accordingly.
 *
 * @example
 * ```tsx
 * <Select
 *   size="large"
 *   options={[
 *     { value: "A", label: "Apple" },
 *     { value: "B", label: "Banana" },
 *   ]}
 * />
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/select/)
 */
export declare const Select: FC<SelectProps>;
export type SelectProps = Omit<SelectHTMLAttributes<HTMLSelectElement>, "size"> & {
    options: Array<OptionHTMLAttributes<HTMLOptionElement>>;
} & BulmaProp & SizeProp<Size> & Partial<{
    isFullwidth: boolean;
    isLoading: boolean;
    isRounded: boolean;
}>;
/**
 * Is a loading element which resembles a paragraph.
 *
 * @example
 * ```tsx
 * <SkeletonLines num={5} />
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/features/skeletons/#skeleton-lines)
 */
export declare const SkeletonLines: FC<SkeletonLinesProps>;
export type SkeletonLinesProps = {
    num: number;
};
/**
 * @see {@link Title}
 */
export declare const Subtitle: FC<PropsWithChildren<SubtitleProps>>;
export type SubtitleProps = Omit<HTMLAttributes<HTMLElement>, "is"> & BulmaProp & IsSkeletonProp & Titlemodifiers;
/**
 * The inevitable HTML table, with special case cells.
 *
 * It <strong>always</strong> renders a <em>scrollable table</em>, that is a table inside a table container like this markup.
 *
 * ```html
 * <div class="table-container">
 *  <table class="table">
 *    <!-- Your table content -->
 *  </table>
 * </div>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/table/)
 */
export declare const Table: FC<PropsWithChildren<TableProps>>;
export type TableProps = TableHTMLAttributes<HTMLTableElement> & BulmaProp;
/**
 * Simple responsive horizontal navigation tabs, with different styles.
 *
 * @example
 * ```tsx
 * <Tabs>
 *     <Tab isActive>Pictures</Tab>
 *     <Tab>Music</Tab>
 *     <Tab>Videos</Tab>
 * </Tabs>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/components/tabs/)
 */
export declare const Tabs: FC<PropsWithChildren<TabsProps>>;
export type TabsProps = HTMLAttributes<HTMLDivElement> & BulmaProp & AlignProp<"center" | "right"> & SizeProp & Partial<{
    isBoxed: boolean;
    isFullwidth: boolean;
    isToggle: boolean;
    isToggleRounded: boolean;
}>;
/** @see {@link Tabs} */
export declare const Tab: FC<PropsWithChildren<TabProps>>;
export type TabProps = AnchorHTMLAttributes<HTMLAnchorElement> & IsActiveProp;
/**
 * Small tag labels to insert anywhere.
 *
 * @example
 * ```tsx
 * <Tag color="primary" variant="light">
 *   v1.0.0
 * </Tag>
 * ```
 *
 * @example Append a delete button.
 * ```tsx
 * <Tag color="warning" size="medium">
 *   Hello
 *    <Delete size="small" />
 * </Tag>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/tag/).
 */
export declare const Tag: FC<PropsWithChildren<TagProps>>;
export type TagProps = HTMLAttributes<HTMLSpanElement> & BulmaProp & ColorProp & ColorVariantProp<"light"> & IsSkeletonProp & SizeProp<"medium" | "large"> & Partial<{
    isHoverable: boolean;
    isRounded: boolean;
}>;
/**
 * List of tags.
 *
 * @example Size.
 * ```tsx
 * <Tags size="large">
 *   <Tag>All</Tag>
 *   <Tag>Medium</Tag>
 *   <Tag>Size</Tag>
 * </Tags>
 * ```
 *
 * @example Attach tags together.
 * ```tsx
 * <Tags hasAddons>
 *   <Tag>package</Tag>
 *   <Tag color="primary">trunx</Tag>
 * </Tags>
 * ```
 *
 * @example Attach a text tag with a delete tag together.
 * ```tsx
 * <Tags hasAddons>
 *   <Tag color="danger">Alex Smith</Tag>
 *   <a class="tag is-delete" />
 * </Tags>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/tag/#list-of-tags)
 */
export declare const Tags: FC<PropsWithChildren<TagsProps>>;
export type TagsProps = HTMLAttributes<HTMLDivElement> & PluralSizeProp & Partial<{
    hasAddons: boolean;
}>;
/**
 * The multiline textarea and its variations.
 *
 * @example
 * ```tsx
 * <Textarea size="small" color="info" />
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/form/textarea/)
 */
export declare const Textarea: FC<TextareaProps>;
export type TextareaProps = TextareaHTMLAttributes<HTMLTextAreaElement> & BulmaProp & ColorProp & IsSkeletonProp & SizeProp<Size> & Partial<{
    isLoading: boolean;
}>;
/**
 * Simple headings to add depth to your page.
 *
 * @example There are two types of heading: Title and Subtitle.
 * ```ts
 * <Title tag="h1">Title</Title>
 * <Subtitle tag="h2">Subtitle</Subtitle>
 * ```
 *
 * @example Sizes
 * ```ts
 * <Title is={1}>Title 1</Title>
 * <Title is={2}>Title 2</Title>
 * <Title is={3}>Title 3 (default)</Title>
 * <Title is={4}>Title 4</Title>
 * <Title is={5}>Title 5</Title>
 * <Title is={6}>Title 6</Title>
 * ```
 * @example Maintain the normal spacing between titles and subtitles.
 * ```ts
 * <Title is={1} isSpaced>Title 1</Title>
 * <Subtitle is={3}>Subtitle 3</Subtitle>
 * ```
 *
 * @example Skeleton
 * ```ts
 * <Title hasSkeleton>Title</Title>
 * ```
 *
 * @see [bulma docs](https://bulma.io/documentation/elements/title/)
 */
export declare const Title: FC<PropsWithChildren<TitleProps>>;
export type TitleProps = Omit<HTMLAttributes<HTMLElement>, "is"> & BulmaProp & IsSkeletonProp & Titlemodifiers & Partial<{
    isSpaced: boolean;
}>;
type Titlemodifiers = TagProp<"h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "p"> & Partial<{
    hasSkeleton: boolean;
    is: 1 | 2 | 3 | 4 | 5 | 6;
}>;
export {};
